==> SnappEmailApiClient-0.3.7.zip: SnappEmailApiClient-0.3.7/snapp_email/endpoints/appointment/AppointmentResponse_20Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import AppointmentResponse_20
from snapp_email.datacontract.utils import export_dict, fill


class AppointmentResponse_20Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, accept_type=None):
        """
        Retrieve options available for resource 'AppointmentResponse_20'.
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: AppointmentResponse_20
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'appointment'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.appointment.response-v5.15+json',
            'Accept': 'application/vnd.4thoffice.appointment.response-v5.15+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers)
        
        return fill(AppointmentResponse_20, response.json())
    
    def update(self, obj, accept_type=None):
        """
        Respond to appointment request.
        
        :param obj: Object to be persisted
        :type obj: AppointmentResponse_20
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: AppointmentResponse_20
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'appointment'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.appointment.response-v5.15+json',
            'Accept': 'application/vnd.4thoffice.appointment.response-v5.15+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('put', endpoint, url_parameters, add_headers, data=json.dumps(data))
        
        return fill(AppointmentResponse_20, response.json())

==> SnappEmailApiClient-0.3.19.zip: SnappEmailApiClient-0.3.19/snapp_email/endpoints/appointment/AppointmentResponse_20Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import AppointmentResponse_20
from snapp_email.datacontract.utils import export_dict, fill


class AppointmentResponse_20Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve options available for resource 'AppointmentResponse_20'.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: AppointmentResponse_20
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'appointment'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.appointment.response-v5.15+json',
            'Accept': 'application/vnd.4thoffice.appointment.response-v5.15+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(AppointmentResponse_20, response.json(), content_type=response.headers['Content-Type'])
    
    def update(self, obj, appointmentId, impersonate_user_id=None, accept_type=None):
        """
        Respond to appointment request.
        
        :param obj: Object to be persisted
        :type obj: AppointmentResponse_20
        
        :param appointmentId: 
        :type appointmentId: 
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: AppointmentResponse_20
        """
        url_parameters = {
        }
        endpoint_parameters = {
            'appointmentId': appointmentId,
        }
        endpoint = 'appointment'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.appointment.response-v5.15+json',
            'Accept': 'application/vnd.4thoffice.appointment.response-v5.15+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('put', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id, data=json.dumps(data))
        
        return fill(AppointmentResponse_20, response.json(), content_type=response.headers['Content-Type'])
